@@ -11,10 +11,15 @@ pub trait Kernel: Display + Clone + PartialEq {
     fn set_default(&self) -> Result<()>;
     fn remove_default(&self) -> Result<()>;
     fn ask_set_default(&self) -> Result<()>;
+    fn is_default(&self) -> bool;
     fn install_and_make_config(&self, force_write: bool) -> Result<()>;
 }
 
-pub fn file_copy<P: AsRef<Path>>(src: P, dest: P) -> Result<()> {
+pub fn file_copy<P, Q>(src: P, dest: Q) -> Result<()>
+where
+    P: AsRef<Path>,
+    Q: AsRef<Path>,
+{
     // Only copy if the dest file is missing / different
     if !dest.as_ref().exists() || !is_same_file(&src, &dest)? {
         fs::copy(&src, &dest)?;
